cheesecake.cheesecake_index.IndexRequiredFiles

Package cheesecake :: Module cheesecake_index :: Class IndexRequiredFiles |
[hide private]
[frames] | no frames]

## Class IndexRequiredFiles
source code

    object --+
             |
         Index --+
                 |
        FilesIndex --+
                     |
                    IndexRequiredFiles

Check for existence of important files, like README or INSTALL.

Nested Classes | [hide private]
Inherited from `Index`: `__metaclass__`

Instance Methods | [hide private]
| compute(self, files_list, dirs_list, package_dir) Compute index value and return it.
Inherited from `FilesIndex`: `get_not_used`, `get_score`, `match_filename` Inherited from `FilesIndex` (private): `_compute_from_rules` Inherited from `Index`: `__getitem__`, `__init__`, `add_info`, `add_subindex`, `compute_with`, `decide`, `decide_after_download`, `decide_before_download`, `get_info`, `print_info`, `remove_subindex` Inherited from `Index` (private): `_get_max_value`, `_get_requirements`, `_iter_indices`, `_print_info_many`, `_print_info_one` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
cheese_files |
cheese_dirs |
max_value |
name |
Inherited from `FilesIndex` (private): `_used_rules` Inherited from `Index`: `details`, `info`, `subindices`, `value` Inherited from `object`: `__class__`

Properties | [hide private]
Inherited from `Index`: `requirements`

Method Details | [hide private]

### compute(self, files_list, dirs_list, package_dir) | source code
Compute index value and return it. By default this method computes sum of all subindices. Override this method when subclassing for different behaviour. Parameters to this function are dynamically prepared with use of get_attributes function. Overrides: Index.compute (inherited documentation)

Class Variable Details | [hide private]

    ### cheese_files Value:
        {<cheesecake.cheesecake_index.OneOf object at 0xb79a150c>: 10,
         <cheesecake.cheesecake_index.OneOf object at 0xb79a180c>: 10,
         <cheesecake.cheesecake_index.OneOf object at 0xb79a182c>: 10,
         <cheesecake.cheesecake_index.OneOf object at 0xb79a1a4c>: 20,
         <cheesecake.cheesecake_index.OneOf object at 0xb79a1aac>: 30,
         <cheesecake.cheesecake_index.OneOf object at 0xb79a1bcc>: 10,
         <cheesecake.cheesecake_index.OneOf object at 0xb79a1bec>: 30,
         <cheesecake.cheesecake_index.OneOf object at 0xb79a1d0c>: 20,
        ...

    ### cheese_dirs Value:
        {<cheesecake.cheesecake_index.OneOf object at 0xb79a186c>: 10,
         <cheesecake.cheesecake_index.OneOf object at 0xb79a1d4c>: 30,
         <cheesecake.cheesecake_index.OneOf object at 0xb79a1f2c>: 30}

    ### max_value Value:
        220

    ### name Value:
        'IndexRequiredFiles'